@@ -4,13 +4,13 @@ from fastapi.security import HTTPBearer
 
 from security.tokens import validate_admin_accesstoken,validate_admin_accesstoken_otp,generate_refresh_tokens,generate_member_access_tokens, validate_member_accesstoken, validate_refreshToken,validate_member_accesstoken_without_expiration,generate_admin_access_tokens,validate_expired_admin_accesstoken
 from security.encrypting_jwt import decode_jwt_token,decode_jwt_token_without_expiration
-
+from repositories.tokens_repo import get_access_tokens,get_access_tokens_no_date_check
 from schemas.tokens_schema import refreshedToken,accessTokenOut
 
 
 token_auth_scheme = HTTPBearer()
-async def verify_token(token: str = Depends(token_auth_scheme)):
-    result = await validate_member_accesstoken(accessToken=token.credentials)
+async def verify_token(token: str = Depends(token_auth_scheme))->accessTokenOut:
+    result = await get_access_tokens(accessToken=token.credentials)
     
     if result==None:
         raise HTTPException(
@@ -18,9 +18,19 @@ async def verify_token(token: str = Depends(token_auth_scheme)):
             detail="Invalid token"
         )
     else:
-        decoded_access_token = await decode_jwt_token(token=token.credentials)
-        return decoded_access_token
+        return result
             
+            
+async def verify_token_to_refresh(token: str = Depends(token_auth_scheme)):
+    result = await get_access_tokens_no_date_check(accessToken=token.credentials)
+    
+    if result==None:
+        raise HTTPException(
+            status_code=status.HTTP_401_UNAUTHORIZED,
+            detail="Invalid token"
+        )
+    else:
+        return result
         
         
         
